epoch_offset_datum

Function epoch_offset_datum 

fn epoch_offset_datum(offset: Duration) -> Datum<'static>
Pack an offset from the Unix epoch into a Datum::TimestampTz.

The offset is rounded to microseconds, the maximum resolution of timestamptz. Rounding is monotone, so it cannot reorder two offsets that were ordered before.