fn epoch_offset_datum(offset: Duration) -> Datum<'static>Expand description
Pack an offset from the Unix epoch into a Datum::TimestampTz.
The offset is rounded to microseconds, the maximum resolution of timestamptz. Rounding is
monotone, so it cannot reorder two offsets that were ordered before.